==> haskell-doctest-driver-gen-0.3.0.5-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.5
visibility:           public
id:                   doctest-driver-gen-0.3.0.5-G9qf4PgyipR3gOsUK7fZOd
key:                  doctest-driver-gen-0.3.0.5-G9qf4PgyipR3gOsUK7fZOd
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2021
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  ed9bf45c3f4c4a265418e04a0eb554f4
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.5-G9qf4PgyipR3gOsUK7fZOd
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-driver-gen-0.3.0.7-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.7
visibility:           public
id:                   doctest-driver-gen-0.3.0.7-K1ME2ntVAOA7QIXf97nQRP
key:                  doctest-driver-gen-0.3.0.7-K1ME2ntVAOA7QIXf97nQRP
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2021
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  92e44d69c16883574a32055cc32085aa
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.7-K1ME2ntVAOA7QIXf97nQRP
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
